DSTokenManager class

Manages authentication tokens for the Magic provider

Constructors

DSTokenManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanupExpiredTokens() → Future<void>
clearTokens() → Future<void>
getActiveTokens() → Map<String, String>
getToken(String userId) → Future<String?>
getTokenExpiration(String token) → DateTime?
isTokenExpired(String token) → bool
isTokenValid(String token) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken(String userId, String newToken, {int? expiresIn}) → Future<void>
removeToken(String userId) → Future<void>
storeToken(String userId, String token, {int? expiresIn}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited